@@ -196,10 +196,16 @@ impl QueryProcessor<TestAggregate> for TestView {
 
 pub type TestEventEnvelope = EventEnvelope<TestAggregate>;
 
-assert_impl_all!(aggregate; TestAggregate,Aggregate);
+assert_impl_all!(TestAggregate: Aggregate);
 // assert_impl_all!(event; TestEvent);
 
-assert_impl_all!(MemoryStore; MemoryStore::<TestAggregate>, EventStore::<TestAggregate,MemoryStoreAggregateContext<TestAggregate>>);
+assert_impl_all!(
+    MemoryStore::<TestAggregate>:
+        EventStore::<
+            TestAggregate,
+            MemoryStoreAggregateContext<TestAggregate>,
+        >
+);
 
 fn metadata() -> HashMap<String, String> {
     let now = "2021-03-18T12:32:45.930Z".to_string();
